@@ -1,19 +1,19 @@
 ;; -*-emacs-lisp-*-
 ;;
-;; Emacs startup file for the Debian netcdf-ifc8.1 package
+;; Emacs startup file for the Debian netcdf-ifc9 package
 ;;
 ;; Originally contributed by Nils Naumann <naumann@unileoben.ac.at>
 ;; Modified by Dirk Eddelbuettel <edd@debian.org>
 ;; Adapted for dh-make by Jim Van Zandt <jrv@vanzandt.mv.com>
 
-;; The netcdf-ifc8.1 package follows the Debian/GNU Linux 'emacsen' policy and
+;; The netcdf-ifc9 package follows the Debian/GNU Linux 'emacsen' policy and
 ;; byte-compiles its elisp files for each 'emacs flavor' (emacs19,
 ;; xemacs19, emacs20, xemacs20...).  The compiled code is then
 ;; installed in a subdirectory of the respective site-lisp directory.
 ;; We have to add this to the load-path:
 (let ((package-dir (concat "/usr/share/"
                            (symbol-name flavor)
-                           "/site-lisp/netcdf-ifc8.1")))
+                           "/site-lisp/netcdf-ifc9")))
   (when (file-directory-p package-dir)
         (setq load-path (cons package-dir load-path))))
 
